package com.iformall.controller;

import com.github.pagehelper.PageInfo;
import com.iformall.common.ErrorCode;
import com.iformall.common.Result;
import com.iformall.common.ResultData;
import com.iformall.controller.base.BaseController;
import com.iformall.domain.po.BaseEntity;
import com.iformall.domain.po.TtMerchantPoi;
import com.iformall.enums.EnumMeterialType;
import com.iformall.service.TtMerchantPoiService;
import com.iformall.service.toutiao.FmTtOpenService;
import com.iformall.service.toutiao.api.TtOpenMaService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import me.chanjar.weixin.common.bean.result.WxMediaUploadResult;
import me.chanjar.weixin.common.error.WxErrorException;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

/**
 * @author gongbiao
 */
@RestController
@RequestMapping("merchantPoi")
public class TtMerchantPoiController extends BaseController {
    private final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private TtMerchantPoiService ttMerchantPoiService;

    @Autowired
    protected FmTtOpenService openService;

    @ApiOperation("分页列表接口")
    @GetMapping("list")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页数", dataType = "int", paramType = "query", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", dataType = "int", paramType = "query", required = true)})
    public ResultData list(@ModelAttribute TtMerchantPoi record, Integer pageNum, Integer pageSize) {
        logger.debug("[" + getIpAddr() + "] TtMerchantPoiController::list");
        if (null == record || StringUtils.isBlank(record.getTenantId())){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }
        record.setSortColumns(BaseEntity.SortField.UpdateDate_DESC);
        final PageInfo<TtMerchantPoi> page = ttMerchantPoiService.listAsPage(record, pageNum, pageSize);
        return new ResultData(page);
    }

    @ApiOperation("根据id查询接口")
    @GetMapping("/findById")
    @ApiImplicitParam(name = "id", value = "id", dataType = "Long", paramType = "query", required = true)
    public ResultData findById(Long id) {
        logger.debug("[" + getIpAddr() + "] TtMerchantPoiController::findById");
        if(id == null){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }
        TtMerchantPoi record = ttMerchantPoiService.getById(id);
        return new ResultData(record);
    }

    /**
     * 代授权小程序上传资源
     * 1	小程序图标	修改小程序图标接口	小于等于 2MB	jpeg、jpg、png	像素为 200 * 200
     * 2	小程序服务类目资质材料	增加服务类目接口
     * 补充服务类目资质信息接口	小于等于 2MB	jpeg、jpg、png
     * 3	小程序名称审核材料	修改小程序名称接口	小于等于 2MB	jpeg、jpg、png
     * 4	小程序落地页截图	申请「短视频挂载」能力接口	小于等于 2MB	jpeg、jpg、png
     * 5	场景示例图	申请「获取用户手机号」能力接口	小于等于 5MB	jpeg、jpg、png
     * 6	小程序分享模板图片	新增分享模板接口
     * 修改分享模板接口	小于等于 1MB	jpeg、jpg、png	像素为 500 * 400
     * 7	商铺营业执照、行业资质材料	提交商铺资质材料接口	小于等于 4MB	jpeg、jpg、png
     * 8	服务商和商家的合作协议	提交商铺资质材料接口	小于等于 4MB	pdf
     *
     * @param multiReq
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/upload_material", consumes = "multipart/*", headers = "content-type=multipart/form-data")
    @ApiOperation("上传图片")
    public ResultData uploadMaterial(@RequestParam("file") MultipartFile multiReq
            ,@RequestParam Map<String, String> param) {
        logger.info("[" + getIpAddr() + "] TtMerchantPoiController::upload_material");
        String appId = param.get("appId");
        if(StringUtils.isBlank(appId)){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }
        String materialTypeStr = param.get("materialType");
        Integer materialType = null;
        if(StringUtils.isNotBlank(materialTypeStr)){
            try{
                materialType = Integer.parseInt(materialTypeStr);
            }catch (Exception e){ }
        }
        if(materialType == null){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }

        EnumMeterialType enumMeterialType = EnumMeterialType.getByCode(materialType);
        if(enumMeterialType == null){
            return new ResultData(ErrorCode.SYS_PARAMETER_ERROR);
        }

        long size = multiReq.getSize();
        final long length = enumMeterialType.getSize();
        if (size > length) {
            return new ResultData(ErrorCode.PICTURE_SIZE_EXCEED);
        }

        String fileFormat = "";
        try {
            int dot = multiReq.getOriginalFilename().lastIndexOf('.');
            if (dot >= 0) {
                fileFormat = multiReq.getOriginalFilename().substring(dot, multiReq.getOriginalFilename().length());
            }

            TtOpenMaService openMaService = openService.getTtOpenComponentService().getTtMaServiceByAppid(appId);
            String res = openMaService.mediaUpload(materialType, fileFormat, multiReq.getInputStream());
            return new ResultData(res);

        } catch (Exception e) {
            logger.error("解析图片",e);
            return new ResultData(ErrorCode.PICTURE_ANALYZING_ERROR);
        }
    }


    @PostMapping(value = "/upload_material1", consumes = "multipart/*", headers = "content-type=multipart/form-data")
    @ApiOperation("上传图片")
    public ResultData uploadMaterial(@RequestParam("file") MultipartFile multiReq) {
        logger.info("[" + getIpAddr() + "] TtMerchantPoiController::upload_material");
        String appId = "ttef6599d8705b49b101";
        if(StringUtils.isBlank(appId)){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }
        String materialTypeStr = "7";
        Integer materialType = null;
        if(StringUtils.isNotBlank(materialTypeStr)){
            try{
                materialType = Integer.parseInt(materialTypeStr);
            }catch (Exception e){ }
        }
        if(materialType == null){
            return new ResultData(ErrorCode.SYS_PARAMETER_NOT_NULL);
        }

        EnumMeterialType enumMeterialType = EnumMeterialType.getByCode(materialType);
        if(enumMeterialType == null){
            return new ResultData(ErrorCode.SYS_PARAMETER_ERROR);
        }

        long size = multiReq.getSize();
        final long length = enumMeterialType.getSize();
        if (size > length) {
            return new ResultData(ErrorCode.PICTURE_SIZE_EXCEED);
        }

        String fileFormat = "";
        try {
            int dot = multiReq.getOriginalFilename().lastIndexOf('.');
            if (dot >= 0) {
                fileFormat = multiReq.getOriginalFilename().substring(dot, multiReq.getOriginalFilename().length());
            }

            TtOpenMaService openMaService = openService.getTtOpenComponentService().getTtMaServiceByAppid(appId);
            String res = openMaService.mediaUpload(materialType, fileFormat, multiReq.getInputStream());
            return new ResultData(res);

        } catch (Exception e) {
            logger.error("解析图片",e);
            return new ResultData(ErrorCode.PICTURE_ANALYZING_ERROR);
        }
    }



}
